const hs = document.documentElement.style;

{
	hs.color = "#222";
}
